@@ -35,9 +35,10 @@ def test_zeroshotclassifier_english(expected_en):
     model_class = model.construct().__class__
     assert model_class == ZeroShotClassifierParameters
     annotator = ZeroShotClassifierAnnotator()
+    candidate_labels = {k: k for k in expected_en.keys()}
     parameters = ZeroShotClassifierParameters(
         model=TrfModel.distilbert_base_uncased_mnli,
-        candidate_labels=",".join(expected_en.keys()),
+        candidate_labels=candidate_labels,
         multi_label=True,
     )
     docs: List[Document] = annotator.annotate(
@@ -52,6 +53,7 @@ def test_zeroshotclassifier_english_segments(expected_en):
     model_class = model.construct().__class__
     assert model_class == ZeroShotClassifierParameters
     annotator = ZeroShotClassifierAnnotator()
+    candidate_labels = {k: k for k in expected_en.keys()}
     doc = Document(text="", sentences=[])
     start = 0
     for text in expected_en.values():
@@ -64,7 +66,7 @@ def test_zeroshotclassifier_english_segments(expected_en):
         doc.sentences[-1].end -= 1
     parameters = ZeroShotClassifierParameters(
         model=TrfModel.distilbert_base_uncased_mnli,
-        candidate_labels=",".join(expected_en.keys()),
+        candidate_labels=candidate_labels,
         processing_unit=ProcessingUnit.segment,
         multi_label=True,
     )
@@ -78,9 +80,10 @@ def test_zeroshotclassifier_french(expected_fr):
     model_class = model.construct().__class__
     assert model_class == ZeroShotClassifierParameters
     annotator = ZeroShotClassifierAnnotator()
+    candidate_labels = {k: k for k in expected_fr.keys()}
     parameters = ZeroShotClassifierParameters(
         model=TrfModel.camembert_base_xnli,
-        candidate_labels=",".join(expected_fr.keys()),
+        candidate_labels=candidate_labels,
         multi_label=True,
     )
     docs: List[Document] = annotator.annotate(
@@ -95,6 +98,7 @@ def test_zeroshotclassifier_french_segments(expected_fr):
     model_class = model.construct().__class__
     assert model_class == ZeroShotClassifierParameters
     annotator = ZeroShotClassifierAnnotator()
+    candidate_labels = {k: k for k in expected_fr.keys()}
     doc = Document(text="", sentences=[])
     start = 0
     for text in expected_fr.values():
@@ -107,7 +111,7 @@ def test_zeroshotclassifier_french_segments(expected_fr):
         doc.sentences[-1].end -= 1
     parameters = ZeroShotClassifierParameters(
         model=TrfModel.camembert_base_xnli,
-        candidate_labels=",".join(expected_fr.keys()),
+        candidate_labels=candidate_labels,
         processing_unit=ProcessingUnit.segment,
         multi_label=True,
     )
